<?php

namespace Bixo\Kpi\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Kpi\Actions\KpiAction;
use Bixo\Kpi\Http\Requests\KpiActionRequest;
use Bixo\Kpi\Http\Resources\KpiResource;
use Bixo\Kpi\Models\Kpi;

/**
 * Admin web controller class.
 */
class KpiActionController extends BaseController
{

    /**
     * Action controller function for kpi.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(KpiActionRequest $request, Kpi $kpi, $action)
    {
        try {
            $request = $request->all();
            $kpi = KpiAction::run($action, $kpi, $request);

            $data = new KpiResource($kpi);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('kpi::kpi.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('kpi/kpi/' . $kpi->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('kpi/kpi/' . $kpi->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
