<?php

namespace Bixo\Kpi\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\Kpi\Http\Resources\KpiResource;
use Bixo\Kpi\Http\Resources\KpisCollection;
use Bixo\Kpi\Scopes\KpiPublicScope;
use Bixo\Kpi\Models\Kpi;

class KpiPublicController extends BaseController
{

    /**
     * Show kpi's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Kpi::pushScope(new RequestScope())
            ->pushScope(new KpiPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $kpis = new KpisCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('kpi::kpi.names'))
            ->view('kpi::public.kpi.index')
            ->data(compact('kpis', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show kpi.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Kpi::findBySlug($slug);
        $data = new KpiResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('kpi::kpi.name'))
            ->view('kpi::public.kpi.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
