<?php

namespace Bixo\Kpi\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Kpi\Events\KpiWorkflow as KpiWorkflowEvent;
use Bixo\Kpi\Notifications\KpiWorkflow as KpiWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class KpiWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(KpiWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $kpi is submitted.
     *
     * @param KpiWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(KpiWorkflowEvent $event)
    {
        $client = $event->kpi->client;
        Notification::send($client, new KpiWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $kpi is published.
     *
     * @param KpiWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(KpiWorkflowEvent $event)
    {
        $client = $event->kpi->client;
        Notification::send($client, new KpiWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $kpi is approved.
     *
     * @param KpiWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(KpiWorkflowEvent $event)
    {
        $client = $event->kpi->client;
        Notification::send($client, new KpiWorkflowNotification($event));
    }

    /**
     * Handles the $kpi workflow event as a listener.
     *
     * @param KpiWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(KpiWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
