<?php

namespace Bixo\Kpi\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Kpi\Models\Kpi;

class KpiPolicy
{

    use KpiAction;
    use KpiExim;
    use KpiReport;

    /**
     * Determine if the given user can view the kpi.
     *
     * @param Authenticatable $user
     * @param Kpi $kpi
     *
     * @return bool
     */
    public function view(Authenticatable $user, Kpi $kpi)
    {
        if ($authUser->canDo('kpi.kpi.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $kpi->is_owner;
    }

    /**
     * Determine if the given user can create a kpi.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('kpi.kpi.create');
    }

    /**
     * Determine if the given user can update the given kpi.
     *
     * @param Authenticatable $user
     * @param Kpi $kpi
     *
     * @return bool
     */
    public function update(Authenticatable $user, Kpi $kpi)
    {
        if ($user->canDo('kpi.kpi.edit') && $user->isAdmin()) {
            return true;
        }

        return $kpi->is_owner;
    }

    /**
     * Determine if the given user can delete the given kpi.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Kpi $kpi)
    {
        return $kpi->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
